EXPORTS
	??0TToneData@@QAE@XZ @ 1 NONAME ; TToneData::TToneData(void)
	?GetDTMFString@TToneData@@QAEPAVTDesC16@@XZ @ 2 NONAME ; class TDesC16 * TToneData::GetDTMFString(void)
	?GetDtmfLenghts@TToneData@@QAEXAAVTTimeIntervalMicroSeconds32@@00@Z @ 3 NONAME ; void TToneData::GetDtmfLenghts(class TTimeIntervalMicroSeconds32 &, class TTimeIntervalMicroSeconds32 &, class TTimeIntervalMicroSeconds32 &)
	?GetDuration@TToneData@@QAEXAAVTTimeIntervalMicroSeconds@@@Z @ 4 NONAME ; void TToneData::GetDuration(class TTimeIntervalMicroSeconds &)
	?GetFrequencyOne@TToneData@@QAEHXZ @ 5 NONAME ; int TToneData::GetFrequencyOne(void)
	?GetFrequencyTwo@TToneData@@QAEHXZ @ 6 NONAME ; int TToneData::GetFrequencyTwo(void)
	?GetRepeatCount@TToneData@@QAEHXZ @ 7 NONAME ; int TToneData::GetRepeatCount(void)
	?GetRepeatTrailingSilence@TToneData@@QAEXAAVTTimeIntervalMicroSeconds@@@Z @ 8 NONAME ; void TToneData::GetRepeatTrailingSilence(class TTimeIntervalMicroSeconds &)
	?GetSequenceData@TToneData@@QAEPAVTDesC8@@XZ @ 9 NONAME ; class TDesC8 * TToneData::GetSequenceData(void)
	?GetSequenceNumber@TToneData@@QAEHXZ @ 10 NONAME ; int TToneData::GetSequenceNumber(void)
	?GetType@TToneData@@QAEXAAW4TToneType@1@@Z @ 11 NONAME ; void TToneData::GetType(enum TToneData::TToneType &)
	?SetDTMFString@TToneData@@QAEXAAVTDesC16@@@Z @ 12 NONAME ; void TToneData::SetDTMFString(class TDesC16 &)
	?SetDtmfLengths@TToneData@@QAEXVTTimeIntervalMicroSeconds32@@00@Z @ 13 NONAME ; void TToneData::SetDtmfLengths(class TTimeIntervalMicroSeconds32, class TTimeIntervalMicroSeconds32, class TTimeIntervalMicroSeconds32)
	?SetDuration@TToneData@@QAEXVTTimeIntervalMicroSeconds@@@Z @ 14 NONAME ; void TToneData::SetDuration(class TTimeIntervalMicroSeconds)
	?SetFrequencyOne@TToneData@@QAEXH@Z @ 15 NONAME ; void TToneData::SetFrequencyOne(int)
	?SetFrequencyTwo@TToneData@@QAEXH@Z @ 16 NONAME ; void TToneData::SetFrequencyTwo(int)
	?SetRepeatCount@TToneData@@QAEXH@Z @ 17 NONAME ; void TToneData::SetRepeatCount(int)
	?SetRepeatTrailingSilence@TToneData@@QAEXVTTimeIntervalMicroSeconds@@@Z @ 18 NONAME ; void TToneData::SetRepeatTrailingSilence(class TTimeIntervalMicroSeconds)
	?SetSequenceData@TToneData@@QAEXAAVTDesC8@@@Z @ 19 NONAME ; void TToneData::SetSequenceData(class TDesC8 &)
	?SetSequenceNumber@TToneData@@QAEXH@Z @ 20 NONAME ; void TToneData::SetSequenceNumber(int)
	?SetType@TToneData@@QAEXW4TToneType@1@@Z @ 21 NONAME ; void TToneData::SetType(enum TToneData::TToneType)

